/*
 * the Decibel Realtime Communication Framework
 * Copyright (C) 2006 by basyskom GmbH
 *  @author Tobias Hunger <info@basyskom.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _DECIBEL_ACCOUNTDATA_H_
#define _DECIBEL_ACCOUNTDATA_H_

namespace Decibel {

/** "Special" names for use in QVariantMaps: */
const QString name_protocol("decibel_protocol");
const QString name_presence("decibel_presence");
const QString name_display_name("decibel_display_name");
const QString name_current_presence("decibel_current_presence");
const QString name_presence_message("decibel_presence_message");
const QString name_autoreconnect("decibel_auto_reconnect");

/** "Normal" Telepathy names: */
const QString name_tp_server("server");
const QString name_tp_account("account");
const QString name_tp_passwort("passwort");
const QString name_tp_port("port");

} // namespace

#endif
